# Morse-Code-Translator
Contains MorseTranslator.py which translates Morse code to English text and vice versa.

This is my Morse code translator project. I'm mainly using it as a learning tool to get a better understanding of open-source code and proper Python coding practices.
When I first wrote this, it was 300 lines of if-else statements in Python 2. My goal is to turn it into something actually usable and readable.
Any suggestions for how to format my code better or comments on general glaring issues in my use of GitHub would be greatly appreciated!

Runs on Python 3.9
